
# This file was generated by 'versioneer.py' (0.29) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-12-03T16:54:31+0100",
 "dirty": true,
 "error": null,
 "full-revisionid": "55c1fa6d62d4db653146ea3b9bff7a07f1b0e6fc",
 "version": "0.3.9"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
